@@ -1,8 +1,8 @@
 ##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Policy/InputOutput/RequireBracedFileHandleWithPrint.pm $
-#     $Date: 2008-07-03 10:19:10 -0500 (Thu, 03 Jul 2008) $
-#   $Author: clonezone $
-# $Revision: 2489 $
+#      $URL$
+#     $Date$
+#   $Author$
+# $Revision$
 ##############################################################################
 
 package Perl::Critic::Policy::InputOutput::RequireBracedFileHandleWithPrint;
@@ -15,14 +15,15 @@ use Readonly;
 use Perl::Critic::Utils qw{ :severities :classification :data_conversion };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.088';
+our $VERSION = '1.121';
 
 #-----------------------------------------------------------------------------
 
 Readonly::Array my @POSTFIX_WORDS => qw( if unless for );
 Readonly::Hash my %POSTFIX_WORDS => hashify( @POSTFIX_WORDS );
+Readonly::Scalar my $PRINT_RX  => qr/ \A (?: print f? | say ) \z /xms;
 
-Readonly::Scalar my $DESC => q{File handle for "print" is not braced};
+Readonly::Scalar my $DESC => q{File handle for "print" or "printf" is not braced};
 Readonly::Scalar my $EXPL => [ 217 ];
 
 #-----------------------------------------------------------------------------
@@ -37,7 +38,7 @@ sub applies_to           { return 'PPI::Token::Word'      }
 sub violates {
     my ( $self, $elem, undef ) = @_;
 
-    return if $elem ne 'print';
+    return if $elem !~ $PRINT_RX;
     return if ! is_function_call($elem);
 
     my @sib;
@@ -59,7 +60,7 @@ sub violates {
     return if !$sib[2];
 
     # First token must be a scalar symbol or bareword;
-    return if !( ($sib[0]->isa('PPI::Token::Symbol') && $sib[0] =~ m/\A \$/mx)
+    return if !( ($sib[0]->isa('PPI::Token::Symbol') && $sib[0] =~ m/\A \$/xms)
                  || $sib[0]->isa('PPI::Token::Word') );
 
     # First token must not be a builtin function or control
@@ -94,17 +95,19 @@ Perl::Critic::Policy::InputOutput::RequireBracedFileHandleWithPrint - Write C<pr
 
 =head1 AFFILIATION
 
-This Policy is part of the core L<Perl::Critic> distribution.
+This Policy is part of the core L<Perl::Critic|Perl::Critic>
+distribution.
 
 
 =head1 DESCRIPTION
 
-The C<print> function has a unique syntax that supports an optional
-file handle argument.  Conway suggests wrapping this argument in
-braces to make it visually stand out from the other arguments.  When
-you put braces around any of the special package-level file handles
-like C<STDOUT>, C<STDERR>, and C<DATA>, you must the C<'*'> sigil or
-else it won't compile under C<use strict 'subs'>.
+The C<print> and C<printf> functions have a unique syntax that
+supports an optional file handle argument.  Conway suggests wrapping
+this argument in braces to make it visually stand out from the other
+arguments.  When you put braces around any of the special
+package-level file handles like C<STDOUT>, C<STDERR>, and C<DATA>, you
+must the C<'*'> sigil or else it won't compile under C<use strict
+'subs'>.
 
   print $FH   "Mary had a little lamb\n";  #not ok
   print {$FH} "Mary had a little lamb\n";  #ok
@@ -121,11 +124,11 @@ This Policy is not configurable except for the standard options.
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <thaljef@cpan.org>
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2008 Jeffrey Ryan Thalhammer.  All rights reserved.
+Copyright (c) 2005-2011 Imaginative Software Systems.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
