@@ -1,8 +1,8 @@
 ##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Policy/ValuesAndExpressions/ProhibitMixedBooleanOperators.pm $
-#     $Date: 2008-07-03 10:19:10 -0500 (Thu, 03 Jul 2008) $
-#   $Author: clonezone $
-# $Revision: 2489 $
+#      $URL$
+#     $Date$
+#   $Author$
+# $Revision$
 ##############################################################################
 
 package Perl::Critic::Policy::ValuesAndExpressions::ProhibitMixedBooleanOperators;
@@ -18,7 +18,7 @@ use base 'Perl::Critic::Policy';
 
 #-----------------------------------------------------------------------------
 
-our $VERSION = '1.088';
+our $VERSION = '1.121';
 #-----------------------------------------------------------------------------
 
 Readonly::Hash my %LOW_BOOLEANS  => hashify( qw( not or and ) );
@@ -47,7 +47,7 @@ Readonly::Scalar my $EXPL => [ 70 ];
 
 sub supported_parameters { return ()                  }
 sub default_severity     { return $SEVERITY_HIGH      }
-sub default_themes       { return qw( core bugs pbp ) }
+sub default_themes       { return qw( core bugs pbp certrec ) }
 sub applies_to           { return 'PPI::Statement'    }
 
 #-----------------------------------------------------------------------------
@@ -104,21 +104,22 @@ Perl::Critic::Policy::ValuesAndExpressions::ProhibitMixedBooleanOperators - Writ
 
 =head1 AFFILIATION
 
-This Policy is part of the core L<Perl::Critic> distribution.
+This Policy is part of the core L<Perl::Critic|Perl::Critic>
+distribution.
 
 
 =head1 DESCRIPTION
 
 Conway advises against combining the low-precedence booleans ( C<and
-or not> ) with the high-precedence boolean operators ( C<&& || !> )
-in the same expression.  Unless you fully understand the differences
+or not> ) with the high-precedence boolean operators ( C<&& || !> ) in
+the same expression.  Unless you fully understand the differences
 between the high and low-precedence operators, it is easy to
 misinterpret expressions that use both.  And even if you do understand
 them, it is not always clear if the author actually intended it.
 
-  next if not $foo || $bar;  #not ok
-  next if !$foo || $bar;     #ok
-  next if !( $foo || $bar ); #ok
+    next if not $foo || $bar;  #not ok
+    next if !$foo || $bar;     #ok
+    next if !( $foo || $bar ); #ok
 
 
 =head1 CONFIGURATION
@@ -128,11 +129,11 @@ This Policy is not configurable except for the standard options.
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <thaljef@cpan.org>
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2008 Jeffrey Ryan Thalhammer.  All rights reserved.
+Copyright (c) 2005-2011 Imaginative Software Systems.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
